@@ -408,7 +408,7 @@ class SocketWrapper(object):
                     break
                 # This may happen in the `V1_0` protocol where we send two requests as
                 # an optimization, then need to read each separately
-                if request is not "":
+                if request != "":
                     self.sendall(request)
 
                 # The response from the server is a null-terminated string
